@@ -16,8 +16,8 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
  *************************************************************************************/
 
-#ifndef MATRIXTEST_H
-#define MATRIXTEST_H
+#ifndef COMMANDSTEST_H
+#define COMMANDSTEST_H
 
 #include <QObject>
 
@@ -30,7 +30,7 @@ class CommandsTest : public QObject
 {
 Q_OBJECT
     public:
-        CommandsTest(QObject *parent = 0);
+        CommandsTest(QObject *parent = nullptr);
         ~CommandsTest();
     
     private Q_SLOTS:
@@ -50,4 +50,4 @@ Q_OBJECT
         Analitza::Analyzer *a;
 };
 
-#endif // MATRIXTEST_H
+#endif // COMMANDSTEST_H
